pydas
=====

.. image:: https://badge.fury.io/py/pydas.png
    :target: http://badge.fury.io/py/pydas
    :alt: PyPI Package Version

.. image:: https://pypip.in/d/pydas/badge.png
    :target: https://pypi.python.org/pypi/pydas/
    :alt: Downloads

.. image:: https://pypip.in/license/pydas/badge.png
    :target: https://pypi.python.org/pypi/pydas/
    :alt: License

Upload data to a `Midas`_-based application with Python.

.. _`Midas`: http://www.midasplatform.org/
